@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-#    Copyright (C) 2008-2009 Ivan Garcia capiscuas@gmail.com
+#    Copyright (C) 2008-2010 Ivan Garcia capiscuas@gmail.com
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
 #    the Free Software Foundation; either version 3 of the License, or
@@ -39,14 +39,12 @@ from SplashScreen import SplashScreen, NoneSplashScreen
 
 from core.languages import Languages as languages
 
-
-import locale
-import gettext
+import locale, gettext
 
 # create splash screen and show messages to the user
 app = QApplication(sys.argv)
 splash = SplashScreen()
-splash.showMessage("Loading modules...")
+splash.showMessage("Loading...")
 QCoreApplication.flush()
 
 from qt import installErrorHandler, Error, _Warning, extension
@@ -113,7 +111,7 @@ class Main(QMainWindow, Ui_MainWindow):
         #Check the default locale
         lc, encoding = locale.getdefaultlocale()
         if not lc:
-            user_locale = 'en' #english will be the default locale in case of not found
+            user_locale = 'en' #In case of language not found
         else:
             if lc in languages.ListAll_locale():
                 user_locale = lc
@@ -125,8 +123,9 @@ class Main(QMainWindow, Ui_MainWindow):
             interface_lang = 'en'
         else:
             if interface_lang == QVariant():
-                interface_lang = self.chooseInterfaceLanguage(user_locale)
-                self.settings.setValue("settings/interfaceLang", QVariant(interface_lang))
+                #Use system default locale
+                interface_lang = user_locale
+                self.settings.setValue("settings/interfaceLang", QVariant(user_locale))
             else:
                 interface_lang = str(interface_lang.toString().toUtf8())
 
@@ -358,7 +357,8 @@ class Main(QMainWindow, Ui_MainWindow):
         try:
             log.debug('Connecting to the Babiloo XMLRPC Server')
             self.OnlineService = OnlineService(self.options.server, self.options.proxy)
-            self.detect_software_updates()
+            if platform.system() in ("Windows", "Microsoft"):
+                self.detect_software_updates()
             return True
         except TimeoutFunctionException:
             log.error('Unable to connect to the Babiloo XMLRPC Server')
@@ -554,7 +554,7 @@ class Main(QMainWindow, Ui_MainWindow):
                "DICT dictionaries (*.dz)"
 
         currentDir = self.settings.value("mainwindow/workingDirectory", QVariant())
-        fileNames = QFileDialog.getOpenFileNames(None, _("Import one or many dictionaries"), currentDir.toString(), importWildCard)
+        fileNames = QFileDialog.getOpenFileNames(None, _("Import one or more dictionaries"), currentDir.toString(), importWildCard)
         fileNames = [str(file.toUtf8()) for file in fileNames]
         if fileNames:
             self.settings.setValue("mainwindow/workingDirectory", QVariant(QFileInfo(fileNames[0]).absolutePath()))
@@ -584,10 +584,10 @@ class Main(QMainWindow, Ui_MainWindow):
                     unsuccessfully_installed.append(filename)
 
             if len(successfully_installed):
-                result_message += _("Dictionary successfully installed:\n %s") % successfully_installed
+                result_message += _("Dictionary successfully installed.")
             if len(unsuccessfully_installed):
-                result_message += "\n" + _("Dictionary that coudn't be installed:\n %s") % successfully_installed
-            QMessageBox.about(self,_("Alert"),result_message)
+                result_message += "\n" + _("Dictionary selected couldn't be installed.")
+            QMessageBox.about(self,_("Info"),result_message)
 
     def loadDictionary(self, mydict):
         log.debug('main::Loading dictionary: %s' % mydict.getName())
